@@ -4,7 +4,7 @@ use super::*;
 pub(crate) enum CompileErrorKind<'src> {
   AliasInvalidAttribute {
     alias: &'src str,
-    attr: Attribute,
+    attribute: Attribute<'src>,
   },
   AliasShadowsRecipe {
     alias: &'src str,
@@ -25,9 +25,11 @@ pub(crate) enum CompileErrorKind<'src> {
     min: usize,
     max: usize,
   },
-  DuplicateAlias {
-    alias: &'src str,
+  Redefinition {
     first: usize,
+    first_type: &'static str,
+    name: &'src str,
+    second_type: &'static str,
   },
   DuplicateAttribute {
     attribute: &'src str,
@@ -37,10 +39,6 @@ pub(crate) enum CompileErrorKind<'src> {
     recipe: &'src str,
     parameter: &'src str,
   },
-  DuplicateRecipe {
-    recipe: &'src str,
-    first: usize,
-  },
   DuplicateSet {
     setting: &'src str,
     first: usize,
@@ -58,7 +56,7 @@ pub(crate) enum CompileErrorKind<'src> {
     found: usize,
     expected: Range<usize>,
   },
-  IncludeMissingPath,
+  Include,
   InconsistentLeadingWhitespace {
     expected: &'src str,
     found: &'src str,
@@ -87,6 +85,9 @@ pub(crate) enum CompileErrorKind<'src> {
   UndefinedVariable {
     variable: &'src str,
   },
+  UnexpectedAttributeArgument {
+    attribute: Attribute<'src>,
+  },
   UnexpectedCharacter {
     expected: char,
   },
@@ -111,9 +112,6 @@ pub(crate) enum CompileErrorKind<'src> {
     recipe: &'src str,
     unknown: &'src str,
   },
-  UnknownDirective {
-    directive: &'src str,
-  },
   UnknownFunction {
     function: &'src str,
   },
