@@ -3,11 +3,14 @@ use super::*;
 #[derive(Debug, Clone)]
 pub(crate) enum Setting<'src> {
   AllowDuplicateRecipes(bool),
+  DotenvFilename(String),
   DotenvLoad(bool),
+  DotenvPath(String),
   Export(bool),
   Fallback(bool),
   IgnoreComments(bool),
   PositionalArguments(bool),
+  Quiet(bool),
   Shell(Shell<'src>),
   Tempdir(String),
   WindowsPowerShell(bool),
@@ -23,10 +26,11 @@ impl<'src> Display for Setting<'src> {
       | Setting::Fallback(value)
       | Setting::IgnoreComments(value)
       | Setting::PositionalArguments(value)
+      | Setting::Quiet(value)
       | Setting::WindowsPowerShell(value) => write!(f, "{value}"),
       Setting::Shell(shell) | Setting::WindowsShell(shell) => write!(f, "{shell}"),
-      Setting::Tempdir(tempdir) => {
-        write!(f, "{tempdir:?}")
+      Setting::DotenvFilename(value) | Setting::DotenvPath(value) | Setting::Tempdir(value) => {
+        write!(f, "{value:?}")
       }
     }
   }
