@@ -1,6 +1,6 @@
 use super::*;
 
-fn test(justfile: &str, value: Value) {
+fn case(justfile: &str, value: Value) {
   Test::new()
     .justfile(justfile)
     .args(["--dump", "--dump-format", "json", "--unstable"])
@@ -10,7 +10,7 @@ fn test(justfile: &str, value: Value) {
 
 #[test]
 fn alias() {
-  test(
+  case(
     "
       alias f := foo
 
@@ -26,6 +26,7 @@ fn alias() {
         }
       },
       "assignments": {},
+      "modules": {},
       "recipes": {
         "foo": {
           "attributes": [],
@@ -33,6 +34,7 @@ fn alias() {
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -48,6 +50,7 @@ fn alias() {
         "export": false,
         "fallback": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "ignore_comments": false,
@@ -61,7 +64,7 @@ fn alias() {
 
 #[test]
 fn assignment() {
-  test(
+  case(
     "foo := 'bar'",
     json!({
       "aliases": {},
@@ -73,6 +76,7 @@ fn assignment() {
         }
       },
       "first": null,
+      "modules": {},
       "recipes": {},
       "settings": {
         "allow_duplicate_recipes": false,
@@ -83,6 +87,7 @@ fn assignment() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -95,7 +100,7 @@ fn assignment() {
 
 #[test]
 fn body() {
-  test(
+  case(
     "
       foo:
         bar
@@ -105,6 +110,7 @@ fn body() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "foo": {
           "attributes": [],
@@ -115,6 +121,7 @@ fn body() {
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -131,6 +138,7 @@ fn body() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -143,7 +151,7 @@ fn body() {
 
 #[test]
 fn dependencies() {
-  test(
+  case(
     "
       foo:
       bar: foo
@@ -152,11 +160,13 @@ fn dependencies() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "bar": {
           "attributes": [],
           "doc": null,
           "name": "bar",
+          "namepath": "bar",
           "body": [],
           "dependencies": [{
             "arguments": [],
@@ -173,6 +183,7 @@ fn dependencies() {
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -190,6 +201,7 @@ fn dependencies() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -202,7 +214,7 @@ fn dependencies() {
 
 #[test]
 fn dependency_argument() {
-  test(
+  case(
     "
       x := 'foo'
       foo *args:
@@ -230,10 +242,12 @@ fn dependency_argument() {
           "value": "foo",
         },
       },
+      "modules": {},
       "recipes": {
         "bar": {
           "doc": null,
           "name": "bar",
+          "namepath": "bar",
           "body": [],
           "dependencies": [{
             "arguments": [
@@ -262,6 +276,7 @@ fn dependency_argument() {
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [
             {
               "name": "args",
@@ -286,6 +301,7 @@ fn dependency_argument() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -298,7 +314,7 @@ fn dependency_argument() {
 
 #[test]
 fn duplicate_recipes() {
-  test(
+  case(
     "
       set allow-duplicate-recipes
       alias f := foo
@@ -316,12 +332,14 @@ fn duplicate_recipes() {
         }
       },
       "assignments": {},
+      "modules": {},
       "recipes": {
         "foo": {
           "body": [],
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [
             {
               "name": "bar",
@@ -346,6 +364,7 @@ fn duplicate_recipes() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -358,18 +377,20 @@ fn duplicate_recipes() {
 
 #[test]
 fn doc_comment() {
-  test(
+  case(
     "# hello\nfoo:",
     json!({
       "aliases": {},
       "first": "foo",
       "assignments": {},
+      "modules": {},
       "recipes": {
         "foo": {
           "body": [],
           "dependencies": [],
           "doc": "hello",
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -387,6 +408,7 @@ fn doc_comment() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -399,12 +421,13 @@ fn doc_comment() {
 
 #[test]
 fn empty_justfile() {
-  test(
+  case(
     "",
     json!({
       "aliases": {},
       "assignments": {},
       "first": null,
+      "modules": {},
       "recipes": {},
       "settings": {
         "allow_duplicate_recipes": false,
@@ -415,6 +438,7 @@ fn empty_justfile() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -427,7 +451,7 @@ fn empty_justfile() {
 
 #[test]
 fn parameters() {
-  test(
+  case(
     "
       a:
       b x:
@@ -440,6 +464,7 @@ fn parameters() {
       "aliases": {},
       "first": "a",
       "assignments": {},
+      "modules": {},
       "recipes": {
         "a": {
           "attributes": [],
@@ -447,6 +472,7 @@ fn parameters() {
           "dependencies": [],
           "doc": null,
           "name": "a",
+          "namepath": "a",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -458,6 +484,7 @@ fn parameters() {
           "dependencies": [],
           "doc": null,
           "name": "b",
+          "namepath": "b",
           "parameters": [
             {
               "name": "x",
@@ -477,6 +504,7 @@ fn parameters() {
           "dependencies": [],
           "doc": null,
           "name": "c",
+          "namepath": "c",
           "parameters": [
             {
               "name": "x",
@@ -496,6 +524,7 @@ fn parameters() {
           "dependencies": [],
           "doc": null,
           "name": "d",
+          "namepath": "d",
           "parameters": [
             {
               "name": "x",
@@ -515,6 +544,7 @@ fn parameters() {
           "dependencies": [],
           "doc": null,
           "name": "e",
+          "namepath": "e",
           "parameters": [
             {
               "name": "x",
@@ -534,6 +564,7 @@ fn parameters() {
           "dependencies": [],
           "doc": null,
           "name": "f",
+          "namepath": "f",
           "parameters": [
             {
               "name": "x",
@@ -558,6 +589,7 @@ fn parameters() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -570,7 +602,7 @@ fn parameters() {
 
 #[test]
 fn priors() {
-  test(
+  case(
     "
       a:
       b: a && c
@@ -580,12 +612,14 @@ fn priors() {
       "aliases": {},
       "assignments": {},
       "first": "a",
+      "modules": {},
       "recipes": {
         "a": {
           "body": [],
           "dependencies": [],
           "doc": null,
           "name": "a",
+          "namepath": "a",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -607,6 +641,7 @@ fn priors() {
           ],
           "doc": null,
           "name": "b",
+          "namepath": "b",
           "private": false,
           "quiet": false,
           "shebang": false,
@@ -619,6 +654,7 @@ fn priors() {
           "dependencies": [],
           "doc": null,
           "name": "c",
+          "namepath": "c",
           "parameters": [],
           "private": false,
           "quiet": false,
@@ -637,6 +673,7 @@ fn priors() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -649,18 +686,20 @@ fn priors() {
 
 #[test]
 fn private() {
-  test(
+  case(
     "_foo:",
     json!({
       "aliases": {},
       "assignments": {},
       "first": "_foo",
+      "modules": {},
       "recipes": {
         "_foo": {
           "body": [],
           "dependencies": [],
           "doc": null,
           "name": "_foo",
+          "namepath": "_foo",
           "parameters": [],
           "priors": 0,
           "private": true,
@@ -678,6 +717,7 @@ fn private() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -690,18 +730,20 @@ fn private() {
 
 #[test]
 fn quiet() {
-  test(
+  case(
     "@foo:",
     json!({
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "foo": {
           "body": [],
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -719,6 +761,7 @@ fn quiet() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "windows_powershell": false,
@@ -731,7 +774,7 @@ fn quiet() {
 
 #[test]
 fn settings() {
-  test(
+  case(
     "
       set dotenv-load
       set dotenv-filename := \"filename\"
@@ -739,6 +782,7 @@ fn settings() {
       set export
       set fallback
       set positional-arguments
+      set quiet
       set ignore-comments
       set shell := ['a', 'b', 'c']
       foo:
@@ -748,12 +792,14 @@ fn settings() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "foo": {
           "body": [["#!bar"]],
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -771,6 +817,7 @@ fn settings() {
         "fallback": true,
         "ignore_comments": true,
         "positional_arguments": true,
+        "quiet": true,
         "shell": {
           "arguments": ["b", "c"],
           "command": "a",
@@ -786,7 +833,7 @@ fn settings() {
 
 #[test]
 fn shebang() {
-  test(
+  case(
     "
       foo:
         #!bar
@@ -795,12 +842,14 @@ fn shebang() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "foo": {
           "body": [["#!bar"]],
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -818,6 +867,7 @@ fn shebang() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir": null,
         "windows_powershell": false,
@@ -830,18 +880,20 @@ fn shebang() {
 
 #[test]
 fn simple() {
-  test(
+  case(
     "foo:",
     json!({
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "foo": {
           "body": [],
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -859,6 +911,7 @@ fn simple() {
         "fallback": false,
         "ignore_comments": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir": null,
         "windows_powershell": false,
@@ -871,7 +924,7 @@ fn simple() {
 
 #[test]
 fn attribute() {
-  test(
+  case(
     "
       [no-exit-message]
       foo:
@@ -880,6 +933,7 @@ fn attribute() {
       "aliases": {},
       "assignments": {},
       "first": "foo",
+      "modules": {},
       "recipes": {
         "foo": {
           "attributes": ["no-exit-message"],
@@ -887,6 +941,7 @@ fn attribute() {
           "dependencies": [],
           "doc": null,
           "name": "foo",
+          "namepath": "foo",
           "parameters": [],
           "priors": 0,
           "private": false,
@@ -902,6 +957,7 @@ fn attribute() {
         "export": false,
         "fallback": false,
         "positional_arguments": false,
+        "quiet": false,
         "shell": null,
         "tempdir" : null,
         "ignore_comments": false,
@@ -912,3 +968,84 @@ fn attribute() {
     }),
   );
 }
+
+#[test]
+fn module() {
+  Test::new()
+    .justfile(
+      "
+      mod foo
+    ",
+    )
+    .tree(tree! {
+      "foo.just": "bar:",
+    })
+    .args(["--dump", "--dump-format", "json", "--unstable"])
+    .test_round_trip(false)
+    .stdout(format!(
+      "{}\n",
+      serde_json::to_string(&json!({
+        "aliases": {},
+        "assignments": {},
+        "first": null,
+        "modules": {
+          "foo": {
+            "aliases": {},
+            "assignments": {},
+            "first": "bar",
+            "modules": {},
+            "recipes": {
+              "bar": {
+                "attributes": [],
+                "body": [],
+                "dependencies": [],
+                "doc": null,
+                "name": "bar",
+                "namepath": "foo::bar",
+                "parameters": [],
+                "priors": 0,
+                "private": false,
+                "quiet": false,
+                "shebang": false,
+              }
+            },
+            "settings": {
+              "allow_duplicate_recipes": false,
+              "dotenv_filename": null,
+              "dotenv_load": null,
+              "dotenv_path": null,
+              "export": false,
+              "fallback": false,
+              "positional_arguments": false,
+              "quiet": false,
+              "shell": null,
+              "tempdir" : null,
+              "ignore_comments": false,
+              "windows_powershell": false,
+              "windows_shell": null,
+            },
+            "warnings": [],
+          },
+        },
+        "recipes": {},
+        "settings": {
+          "allow_duplicate_recipes": false,
+          "dotenv_filename": null,
+          "dotenv_load": null,
+          "dotenv_path": null,
+          "export": false,
+          "fallback": false,
+          "positional_arguments": false,
+          "quiet": false,
+          "shell": null,
+          "tempdir" : null,
+          "ignore_comments": false,
+          "windows_powershell": false,
+          "windows_shell": null,
+        },
+        "warnings": [],
+      }))
+      .unwrap()
+    ))
+    .run();
+}
